@@ -6,29 +6,48 @@ class BaseTab(Frame):
    def __init__(self, master = None, **kw):
       super().__init__(master, **kw)
       
-      self._frame = Frame(self)
-      self._frame.pack(expand = True)
+      self.__frame = Frame(self)
+      self.__frame.pack(expand = True)
    
    @property
-   def caption(self):
-      return self._config["caption"]
+   def baseTabCaption(self):
+      return self.__config["caption"]
+   
+   @property
+   def baseTabConfig(self):
+      return self.__config
+   
+   @property
+   def baseTabFrame(self):
+      return self.__frame
+   
+   def dumpNamedChildren(self):
+      from .ttk.containers.basecontainer import BaseContainer
+      
+      def dump(container):
+         for name, child in container.getSmartWidget().items():
+            print(name, type(child))
+            
+            if isinstance(child, BaseContainer):
+               dump(child)
+      
+      print(self.baseTabCaption)
+      
+      dump(self.__ui)
+   
+   def getSmartWidget(self, *keys, named = True):
+      return self.__ui.getSmartWidget(*keys, named = named)
    
    def onDeleteWindow(self):
       pass
    
-   def _getValue(self, *keys):
-      proxy = self._ui
-      
-      for key in keys:
-         proxy = proxy[key]
-      
-      return proxy.value.getValue()
-   
    def _inflate(self, config):
-      self._config = config
+      self.__config = config
       
-      if "ui" in self._config:
-         self._ui = CommonUIComponents.inflate(self._frame, self._config)
+      if "ui" in config:
+         self.__ui = CommonUIComponents.inflate(self)
+         
+         self.__ui.grid()
 
 
 class BaseTabLoader:
@@ -51,7 +70,7 @@ class BaseTabLoader:
          
          tabs[name] = tab
          
-         notebook.add(tab, text = tab.caption)
+         notebook.add(tab, text = tab.baseTabCaption)
       
       notebook.select(selectedIndex)
       
